/* New Chat Display Widget Styles */
.sage-ai-new-chat-display {
  flex: 1;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  padding: 2rem;
  height: 100% !important;
  overflow: auto;
}

.sage-ai-new-chat-container {
  max-width: 400px;
  width: 100%;
  text-align: center;
  justify-self: center;
}

.sage-ai-new-chat-title-section {
  margin-bottom: 2rem;
  text-align: center !important;
}

.sage-ai-new-chat-title {
  font-size: 13px;
  font-weight: 400;
  color: var(--jp-ui-font-color2);
  font-size: 13px;
  font-weight: 600;
  color: var(--jp-ui-font-color2);
  margin: 0 0 0.5rem 0;
  text-align: center;
}

.sage-ai-new-chat-help {
  font-size: 15px;
  font-weight: 500;
  color: var(--jp-ui-font-color0);
  font-size: 16px;
  color: var(--jp-ui-font-color1);
  margin: 0;
  text-align: center;
  font-weight: 600;
}

.sage-ai-new-chat-prompts-section {
  text-align: left;
}

.sage-ai-new-chat-prompts-title {
  font-size: 0.9rem;
  font-weight: 500;
  color: var(--jp-ui-font-color2);
  margin: 0 0 1rem 0;
}

.sage-ai-new-chat-prompts-list {
  display: flex;
  flex-direction: column;
  justify-content: center;
  width: 100%;
  gap: 0.5rem;
}

.sage-ai-new-chat-prompt-button {
  background: var(--jp-layout-color2);
  border-radius: 12px !important;
  border: none;
  color: var(--jp-ui-font-color0);
  text-align: left;
  cursor: pointer;
  transition: all 0.2s ease;
  line-height: 1.4;
  padding: 4px 14px;
  justify-content: center;
  align-items: center;
  width: fit-content;
  font-size: 13px;
  align-self: center;
}

.sage-ai-new-chat-prompt-button:hover {
  background: var(--jp-layout-color3);
  border-color: var(--jp-brand-color1);
  transform: translateY(-1px);
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
}

.sage-ai-new-chat-prompt-button:active {
  transform: translateY(0);
  box-shadow: 0 1px 4px rgba(0, 0, 0, 0.1);
}

.sage-ai-new-chat-prompt-button:focus {
  outline: none;
  border-color: var(--jp-brand-color1);
  box-shadow: 0 0 0 2px rgba(54, 124, 226, 0.2);
}
